@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2001  Internet Software Consortium.
+ * Copyright (C) 1999-2002  Internet Software Consortium.
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -15,7 +15,7 @@
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: ncache.c,v 1.23.4.1.10.1 2003/09/17 07:19:47 tale Exp $ */
+/* $Id: ncache.c,v 1.24.2.2.6.1 2003/09/17 05:40:39 explorer Exp $ */
 
 #include <config.h>
 
@@ -260,7 +260,7 @@ dns_ncache_towire(dns_rdataset_t *rdataset, dns_compress_t *cctx,
 {
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	isc_result_t result;
-	isc_region_t remaining, tremaining;
+	isc_region_t remaining, tavailable;
 	isc_buffer_t source, savedbuffer, rdlen;
 	dns_name_t name;
 	dns_rdatatype_t type;
@@ -326,8 +326,8 @@ dns_ncache_towire(dns_rdataset_t *rdataset, dns_compress_t *cctx,
 			 * See if we have space for type, class, ttl, and
 			 * rdata length.  Write the type, class, and ttl.
 			 */
-			isc_buffer_remainingregion(target, &tremaining);
-			if (tremaining.length < 10) {
+			isc_buffer_availableregion(target, &tavailable);
+			if (tavailable.length < 10) {
 				result = ISC_R_NOSPACE;
 				goto rollback;
 			}
